==> foundation-ui-components-1.10.0-cx130-872.1.tgz: package/src/common/card/NsXLargeCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsImage } from '../';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsXLargeCardProps = {
    title: string;
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundColor: '#fff',
        display: 'flex',
        height: '545px',
        width: '375px',
        position: 'relative',
        '.image': {
            width: '100%',
            height: '100%',
            objectFit: 'cover',
        },
        '.gradientOverlay': {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            background: 'linear-gradient(to top, rgba(0,0,0,0.6) 0%, transparent 50%);',
        },
        '.content': {
            position: 'absolute',
            height: '100%',
            width: '100%',
            padding: '40px 40px 25px 30px',
            display: 'flex',
            flexDirection: 'column',
        },
        '.subtitle': {
            color: '#fff',
            fontSize: '11px',
            fontWeight: '400',
            marginTop: 'auto',
        },
        '.title': {
            color: '#fff',
            fontSize: '26px',
            fontWeight: '400',
            marginTop: '20px',
        },
        '.cta': {
            marginTop: '20px',
        },
    };
});

export default function NsXLargeCard({
    title,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
}: NsXLargeCardProps) {
    return (
        <CardContainer className={className} role="x-large-card" component="div" data-testid="x-large-card">
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="gradientOverlay"></div>
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.28.0-cx130-1216.1.tgz: package/src/common/card/NsXLargeCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';
import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsXLargeCardProps = {
    title: string;
    subtitle: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundColor: '#fff',
        display: 'flex',
        height: '620px',
        width: '450px',
        position: 'relative',
        '.image': {
            width: '100%',
            height: '100%',
            objectFit: 'cover',
        },
        '.gradientOverlay': {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            background: 'linear-gradient(to top, rgba(0,0,0,0.6) 0%, transparent 50%);',
        },
        '.content': {
            position: 'absolute',
            height: '100%',
            width: '100%',
            padding: '40px 40px 25px 30px',
            display: 'flex',
            flexDirection: 'column',
        },
        '.subtitle': {
            color: '#fff',
            fontSize: '11px',
            fontWeight: '400',
            marginTop: 'auto',
        },
        '.title': {
            color: '#fff',
            fontSize: '26px',
            fontWeight: '400',
            marginTop: '20px',
        },
        '.cta': {
            marginTop: '20px',
        },
    };
});

export default function NsXLargeCard({ title, subtitle, backgroundImageDetail, button, className }: NsXLargeCardProps) {
    return (
        <CardContainer className={className} role="x-large-card" component="div" data-testid="x-large-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="gradientOverlay"></div>
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
